@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013,2017 Aurimas Cernius
+ * Copyright (C) 2013,2017,2019 Aurimas Cernius
  * Copyright (C) 2011 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -22,21 +22,19 @@
 #ifndef __TRIEHIT_HPP_
 #define __TRIEHIT_HPP_
 
-#include <list>
+#include <memory>
 
 #include <glibmm/ustring.h>
 
-#include "base/macros.hpp"
-
 namespace gnote {
 
 template<class value_t>
 class TrieHit
 {
 public:
-  typedef shared_ptr<TrieHit> Ptr;
-  typedef std::list<Ptr> List;
-  typedef shared_ptr<List> ListPtr;
+  typedef std::shared_ptr<TrieHit> Ptr;
+  typedef std::vector<Ptr> List;
+  typedef std::shared_ptr<List> ListPtr;
 
   TrieHit(int s, int e, const Glib::ustring & k, const value_t & v)
     : m_start(s)
